{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "$(inputs.vector_memory_limit * 1000000000)",
                            "envName": "R_MAX_VSIZE"
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/sc-tools:v0.0.4"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#sc-rna-cluster.cwl/cluster_metric/euclidean",
                                "#sc-rna-cluster.cwl/cluster_metric/cosine",
                                "#sc-rna-cluster.cwl/cluster_metric/manhattan",
                                "#sc-rna-cluster.cwl/cluster_metric/hamming"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--ametric"
                    },
                    "doc": "Distance metric used when constructing nearest-neighbor graph before clustering.\nDefault: euclidean\n",
                    "id": "#sc-rna-cluster.cwl/cluster_metric"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--dimensions"
                    },
                    "doc": "Dimensionality to use when constructing nearest-neighbor graph before clustering\n(from 1 to 50). If single value N is provided, use from 1 to N dimensions. If\nmultiple values are provided, subset to only selected dimensions.\nDefault: from 1 to 10\n",
                    "id": "#sc-rna-cluster.cwl/dimensions"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--h5seurat"
                    },
                    "doc": "Save Seurat data to h5seurat file.\nDefault: false\n",
                    "id": "#sc-rna-cluster.cwl/export_h5seurat_data"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--pdf"
                    },
                    "doc": "Export plots in PDF.\nDefault: false\n",
                    "id": "#sc-rna-cluster.cwl/export_pdf_plots"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--cbbuild"
                    },
                    "doc": "Export results to UCSC Cell Browser. Default: false\n",
                    "id": "#sc-rna-cluster.cwl/export_ucsc_cb"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--genes"
                    },
                    "doc": "Genes of interest to build genes expression plots.\nDefault: None\n",
                    "id": "#sc-rna-cluster.cwl/genes_of_interest"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--diffgenes"
                    },
                    "doc": "Identify differentially expressed genes (putative gene markers) between each\npair of clusters for all resolutions.\nDefault: false\n",
                    "id": "#sc-rna-cluster.cwl/identify_diff_genes"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--logfc"
                    },
                    "doc": "For putative gene markers identification include only those genes that\non average have log fold change difference in expression between every\ntested pair of clusters not lower than this value. Ignored if '--diffgenes'\nis not set.\nDefault: 0.25\n",
                    "id": "#sc-rna-cluster.cwl/minimum_logfc"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--minpct"
                    },
                    "doc": "For putative gene markers identification include only those genes that\nare detected in not lower than this fraction of cells in either of the\ntwo tested clusters. Ignored if '--diffgenes' is not set.\nDefault: 0.1\n",
                    "id": "#sc-rna-cluster.cwl/minimum_pct"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--onlypos"
                    },
                    "doc": "For putative gene markers identification return only positive markers.\nIgnored if '--diffgenes' is not set.\nDefault: false\n",
                    "id": "#sc-rna-cluster.cwl/only_positive_diff_genes"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "Output prefix.\nDefault: ./sc\n",
                    "id": "#sc-rna-cluster.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--memory"
                    },
                    "doc": "Maximum memory in GB allowed to be shared between the workers\nwhen using multiple --cpus.\nDefault: 32\n",
                    "id": "#sc-rna-cluster.cwl/parallel_memory_limit"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--query"
                    },
                    "doc": "Path to the RDS file to load Seurat object from. This file should include genes\nexpression information stored in the RNA assay, as well as 'pca' and 'rnaumap'\ndimensionality reductions applied to that assay.\n",
                    "id": "#sc-rna-cluster.cwl/query_data_rds"
                },
                {
                    "type": [
                        "null",
                        "float",
                        {
                            "type": "array",
                            "items": "float"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--resolution"
                    },
                    "doc": "Clustering resolution applied to the constructed nearest-neighbor graph.\nCan be set as an array.\nDefault: 0.3, 0.5, 1.0\n",
                    "id": "#sc-rna-cluster.cwl/resolution"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#sc-rna-cluster.cwl/test_to_use/wilcox",
                                "#sc-rna-cluster.cwl/test_to_use/bimod",
                                "#sc-rna-cluster.cwl/test_to_use/roc",
                                "#sc-rna-cluster.cwl/test_to_use/t",
                                "#sc-rna-cluster.cwl/test_to_use/negbinom",
                                "#sc-rna-cluster.cwl/test_to_use/poisson",
                                "#sc-rna-cluster.cwl/test_to_use/LR",
                                "#sc-rna-cluster.cwl/test_to_use/MAST",
                                "#sc-rna-cluster.cwl/test_to_use/DESeq2"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--testuse"
                    },
                    "doc": "Statistical test to use for putative gene markers identification.\nIgnored if '--diffgenes' is not set.\nDefault: wilcox\n",
                    "id": "#sc-rna-cluster.cwl/test_to_use"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cpus"
                    },
                    "doc": "Number of cores/cpus to use.\nDefault: 1\n",
                    "id": "#sc-rna-cluster.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 128,
                    "doc": "Maximum vector memory in GB allowed to be used by R.\nDefault: 128\n",
                    "id": "#sc-rna-cluster.cwl/vector_memory_limit"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--verbose"
                    },
                    "doc": "Print debug information.\nDefault: false\n",
                    "id": "#sc-rna-cluster.cwl/verbose"
                }
            ],
            "baseCommand": [
                "sc_rna_cluster.R"
            ],
            "stdout": "sc_rna_cluster_stdout.log",
            "stderr": "sc_rna_cluster_stderr.log",
            "label": "Single-cell RNA-Seq Cluster Analysis",
            "doc": "Single-cell RNA-Seq Cluster Analysis\n\nClusters single-cell RNA-Seq datasets, identifies gene markers.\n",
            "id": "#sc-rna-cluster.cwl",
            "http://schema.org/name": "Single-cell RNA-Seq Cluster Analysis",
            "http://schema.org/alternateName": "Clusters single-cell RNA-Seq datasets, identifies gene markers",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/scRNA-Seq-Analysis/main/tools/sc-rna-cluster.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/scRNA-Seq-Analysis",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_clst_spl_cnd_res_*.pdf"
                    },
                    "doc": "Grouped by cluster split by condition cells composition plot. Downsampled.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_clst_spl_cnd_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_clst_spl_cnd_res_*.png"
                    },
                    "doc": "Grouped by cluster split by condition cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_clst_spl_cnd_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_clst_spl_idnt_res_*.pdf"
                    },
                    "doc": "Grouped by cluster split by dataset cells composition plot. Downsampled.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_clst_spl_idnt_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_clst_spl_idnt_res_*.png"
                    },
                    "doc": "Grouped by cluster split by dataset cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_clst_spl_idnt_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_cnd_spl_clst_res_*.pdf"
                    },
                    "doc": "Grouped by condition split by cluster cells composition plot. Downsampled.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_cnd_spl_clst_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_cnd_spl_clst_res_*.png"
                    },
                    "doc": "Grouped by condition split by cluster cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_cnd_spl_clst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_idnt_spl_clst_res_*.pdf"
                    },
                    "doc": "Grouped by dataset split by cluster cells composition plot. Downsampled.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_idnt_spl_clst_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_idnt_spl_clst_res_*.png"
                    },
                    "doc": "Grouped by dataset split by cluster cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_idnt_spl_clst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_ph_spl_clst_res_*.pdf"
                    },
                    "doc": "Grouped by cell cycle phase split by cluster cells composition plot. Downsampled.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_ph_spl_clst_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_ph_spl_clst_res_*.png"
                    },
                    "doc": "Grouped by cell cycle phase split by cluster cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_ph_spl_clst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_ph_spl_idnt_res_*.pdf"
                    },
                    "doc": "Grouped by cell cycle phase split by dataset cells composition plot. Downsampled.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_ph_spl_idnt_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_cmp_gr_ph_spl_idnt_res_*.png"
                    },
                    "doc": "Grouped by cell cycle phase split by dataset cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/cmp_gr_ph_spl_idnt_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_gene_markers.tsv"
                    },
                    "doc": "Differentially expressed genes between each pair of clusters for all resolutions.\nTSV format\n",
                    "id": "#sc-rna-cluster.cwl/gene_markers_tsv"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_data.h5seurat"
                    },
                    "doc": "Reduced Seurat data in h5seurat format\n",
                    "id": "#sc-rna-cluster.cwl/seurat_data_h5seurat"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_data.rds"
                    },
                    "doc": "Reduced Seurat data in RDS format\n",
                    "id": "#sc-rna-cluster.cwl/seurat_data_rds"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_slh_res_*.pdf"
                    },
                    "doc": "Silhouette scores. Downsampled to max 500 cells per cluster.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/slh_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_slh_res_*.png"
                    },
                    "doc": "Silhouette scores. Downsampled to max 500 cells per cluster.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/slh_res_plot_png"
                },
                {
                    "type": "File",
                    "id": "#sc-rna-cluster.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "sc_rna_cluster_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#sc-rna-cluster.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "sc_rna_cluster_stdout.log"
                    }
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "*_cellbrowser"
                    },
                    "doc": "Directory with UCSC Cellbrowser configuration data.\n",
                    "id": "#sc-rna-cluster.cwl/ucsc_cb_config_data"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "*_cellbrowser/html_data"
                    },
                    "doc": "Directory with UCSC Cellbrowser html data.\n",
                    "id": "#sc-rna-cluster.cwl/ucsc_cb_html_data"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_cellbrowser/html_data/index.html"
                    },
                    "doc": "HTML index file from the directory with UCSC Cellbrowser html data.\n",
                    "id": "#sc-rna-cluster.cwl/ucsc_cb_html_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_res_*.pdf"
                    },
                    "doc": "Clustered cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/umap_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_res_*.png"
                    },
                    "doc": "Clustered cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/umap_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_cnd_res_*.pdf"
                    },
                    "doc": "Split by grouping condition clustered cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/umap_spl_cnd_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_cnd_res_*.png"
                    },
                    "doc": "Split by grouping condition clustered cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/umap_spl_cnd_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_idnt_res_*.pdf"
                    },
                    "doc": "Split by dataset clustered cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/umap_spl_idnt_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_idnt_res_*.png"
                    },
                    "doc": "Split by dataset clustered cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/umap_spl_idnt_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_ph_res_*.pdf"
                    },
                    "doc": "Split by cell cycle phase clustered cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/umap_spl_ph_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_ph_res_*.png"
                    },
                    "doc": "Split by cell cycle phase clustered cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/umap_spl_ph_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_xpr_avg_res_*.pdf"
                    },
                    "doc": "Log normalized scaled average gene expression per cluster.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/xpr_avg_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_xpr_avg_res_*.png"
                    },
                    "doc": "Log normalized scaled average gene expression per cluster.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/xpr_avg_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_xpr_dnst_res_*.pdf"
                    },
                    "doc": "Log normalized gene expression density per cluster.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/xpr_dnst_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_xpr_dnst_res_*.png"
                    },
                    "doc": "Log normalized gene expression density per cluster.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/xpr_dnst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_xpr_per_cell_res_*.pdf"
                    },
                    "doc": "Log normalized gene expression on cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-cluster.cwl/xpr_per_cell_res_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*_xpr_per_cell_res_*.png"
                    },
                    "doc": "Log normalized gene expression on cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-cluster.cwl/xpr_per_cell_res_plot_png"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "dummy_metadata.csv",
                            "entry": "library_id\nExperiment\n"
                        }
                    ]
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "$(inputs.vector_memory_limit * 1000000000)",
                            "envName": "R_MAX_VSIZE"
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/sc-tools:v0.0.4"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Path to the metadata TSV/CSV file to set the datasets identities. If '--mex' points to\nthe Cell Ranger Aggregate outputs, the aggregation.csv file can be used. If input is not\nprovided, the default dummy_metadata.csv will be used instead.\n",
                    "id": "#sc-rna-filter.cwl/aggregation_metadata"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--barcodes"
                    },
                    "doc": "Path to the headerless TSV/CSV file with the list of barcodes to select\ncells of interest (one barcode per line). Prefilters input feature-barcode\nmatrix to include only selected cells.\nDefault: use all cells.\n",
                    "id": "#sc-rna-filter.cwl/barcodes_data"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--h5seurat"
                    },
                    "doc": "Save Seurat data to h5seurat file.\nDefault: false\n",
                    "id": "#sc-rna-filter.cwl/export_h5seurat_data"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--pdf"
                    },
                    "doc": "Export plots in PDF.\nDefault: false\n",
                    "id": "#sc-rna-filter.cwl/export_pdf_plots"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--mex"
                    },
                    "doc": "Path to the folder with feature-barcode matrix from Cell Ranger Count/Aggregate\nexperiment in MEX format.\n",
                    "id": "#sc-rna-filter.cwl/feature_bc_matrices_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--grouping"
                    },
                    "doc": "Path to the TSV/CSV file to define datasets grouping. First column - 'library_id'\nwith the values and order that correspond to the 'library_id' column from the\n'--identity' file, second column 'condition'.\nDefault: each dataset is assigned to its own group.\n",
                    "id": "#sc-rna-filter.cwl/grouping_data"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--maxgenes"
                    },
                    "doc": "Include cells with the number of genes not bigger than this value. If multiple\nvalues provided, each of them will be applied to the correspondent dataset from\nthe '--mex' input based on the '--identity' file.\nDefault: 5000 (applied to all datasets)\n",
                    "id": "#sc-rna-filter.cwl/maximum_genes"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--maxmt"
                    },
                    "doc": "Include cells with the percentage of transcripts mapped to mitochondrial\ngenes not bigger than this value.\nDefault: 5 (applied to all datasets)\n",
                    "id": "#sc-rna-filter.cwl/maximum_mito_perc"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--mingenes"
                    },
                    "doc": "Include cells where at least this many genes are detected. If multiple values\nprovided, each of them will be applied to the correspondent dataset from the\n'--mex' input based on the '--identity' file.\nDefault: 250 (applied to all datasets)\n",
                    "id": "#sc-rna-filter.cwl/minimum_genes"
                },
                {
                    "type": [
                        "null",
                        "float",
                        {
                            "type": "array",
                            "items": "float"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--minnovelty"
                    },
                    "doc": "Include cells with the novelty score not lower than this value, calculated for\nas log10(genes)/log10(UMI). If multiple values provided, each of them will\nbe applied to the correspondent dataset from the '--mex' input based on the\n'--identity' file.\nDefault: 0.8 (applied to all datasets)\n",
                    "id": "#sc-rna-filter.cwl/minimum_novelty_score"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--mitopattern"
                    },
                    "doc": "Regex pattern to identify mitochondrial genes.\nDefault: '^Mt-'\n",
                    "id": "#sc-rna-filter.cwl/mito_pattern"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "Output prefix.\nDefault: ./sc\n",
                    "id": "#sc-rna-filter.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--memory"
                    },
                    "doc": "Maximum memory in GB allowed to be shared between the workers\nwhen using multiple --cpus.\nDefault: 32\n",
                    "id": "#sc-rna-filter.cwl/parallel_memory_limit"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--rnamincells"
                    },
                    "doc": "Include only genes detected in at least this many cells.\nDefault: 5 (applied to all datasets)\n",
                    "id": "#sc-rna-filter.cwl/rna_minimum_cells"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--rnaminumi"
                    },
                    "doc": "Include cells where at least this many UMI (transcripts) are detected.\nIf multiple values provided, each of them will be applied to the correspondent\ndataset from the '--mex' input based on the '--identity' file.\nDefault: 500 (applied to all datasets)\n",
                    "id": "#sc-rna-filter.cwl/rna_minimum_umi"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cpus"
                    },
                    "doc": "Number of cores/cpus to use.\nDefault: 1\n",
                    "id": "#sc-rna-filter.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 128,
                    "doc": "Maximum vector memory in GB allowed to be used by R.\nDefault: 128\n",
                    "id": "#sc-rna-filter.cwl/vector_memory_limit"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--verbose"
                    },
                    "doc": "Print debug information.\nDefault: false\n",
                    "id": "#sc-rna-filter.cwl/verbose"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_1_2_qc_mtrcs_pca.pdf"
                    },
                    "doc": "PC1 and PC2 from the QC metrics PCA (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_1_2_qc_mtrcs_pca_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_1_2_qc_mtrcs_pca.png"
                    },
                    "doc": "PC1 and PC2 from the QC metrics PCA (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_1_2_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_2_3_qc_mtrcs_pca.pdf"
                    },
                    "doc": "PC2 and PC3 from the QC metrics PCA (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_2_3_qc_mtrcs_pca_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_2_3_qc_mtrcs_pca.png"
                    },
                    "doc": "PC2 and PC3 from the QC metrics PCA (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_2_3_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_cells_count.pdf"
                    },
                    "doc": "Number of cells per dataset (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_cells_count_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_cells_count.png"
                    },
                    "doc": "Number of cells per dataset (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_cells_count_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_gene_dnst.pdf"
                    },
                    "doc": "Genes per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_gene_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_gene_dnst.png"
                    },
                    "doc": "Genes per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_gene_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_gene_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition genes per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_gene_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_gene_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition genes per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_gene_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_gene_umi_corr.pdf"
                    },
                    "doc": "Genes vs UMI per cell correlation (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_gene_umi_corr_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_gene_umi_corr.png"
                    },
                    "doc": "Genes vs UMI per cell correlation (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_gene_umi_corr_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_mito_dnst.pdf"
                    },
                    "doc": "Percentage of transcripts mapped to mitochondrial genes per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_mito_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_mito_dnst.png"
                    },
                    "doc": "Percentage of transcripts mapped to mitochondrial genes per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_mito_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_mito_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition the percentage of transcripts mapped\nto mitochondrial genes per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_mito_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_mito_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition the percentage of transcripts mapped\nto mitochondrial genes per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_mito_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_nvlt_dnst.pdf"
                    },
                    "doc": "Novelty score per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_nvlt_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_nvlt_dnst.png"
                    },
                    "doc": "Novelty score per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_nvlt_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_nvlt_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition the novelty score per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_nvlt_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_nvlt_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition the novelty score per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_nvlt_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_qc_mtrcs_dnst.pdf"
                    },
                    "doc": "QC metrics per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_qc_mtrcs_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_qc_mtrcs_dnst.png"
                    },
                    "doc": "QC metrics per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_qc_mtrcs_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_umi_dnst.pdf"
                    },
                    "doc": "UMI per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_umi_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_umi_dnst.png"
                    },
                    "doc": "UMI per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_umi_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_umi_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition UMI per cell density (filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/fltr_umi_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_fltr_umi_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition UMI per cell density (filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/fltr_umi_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_1_2_qc_mtrcs_pca.pdf"
                    },
                    "doc": "PC1 and PC2 from the QC metrics PCA (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_1_2_qc_mtrcs_pca_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_1_2_qc_mtrcs_pca.png"
                    },
                    "doc": "PC1 and PC2 from the QC metrics PCA (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_1_2_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_2_3_qc_mtrcs_pca.pdf"
                    },
                    "doc": "PC2 and PC3 from the QC metrics PCA (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_2_3_qc_mtrcs_pca_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_2_3_qc_mtrcs_pca.png"
                    },
                    "doc": "PC2 and PC3 from the QC metrics PCA (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_2_3_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_cells_count.pdf"
                    },
                    "doc": "Number of cells per dataset (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_cells_count_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_cells_count.png"
                    },
                    "doc": "Number of cells per dataset (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_cells_count_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_gene_dnst.pdf"
                    },
                    "doc": "Genes per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_gene_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_gene_dnst.png"
                    },
                    "doc": "Genes per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_gene_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_gene_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition genes per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_gene_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_gene_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition genes per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_gene_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_gene_umi_corr.pdf"
                    },
                    "doc": "Genes vs UMI per cell correlation (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_gene_umi_corr_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_gene_umi_corr.png"
                    },
                    "doc": "Genes vs UMI per cell correlation (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_gene_umi_corr_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_mito_dnst.pdf"
                    },
                    "doc": "Percentage of transcripts mapped to mitochondrial genes per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_mito_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_mito_dnst.png"
                    },
                    "doc": "Percentage of transcripts mapped to mitochondrial genes per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_mito_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_mito_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition the percentage of transcripts mapped\nto mitochondrial genes per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_mito_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_mito_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition the percentage of transcripts mapped\nto mitochondrial genes per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_mito_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_nvlt_dnst.pdf"
                    },
                    "doc": "Novelty score per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_nvlt_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_nvlt_dnst.png"
                    },
                    "doc": "Novelty score per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_nvlt_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_nvlt_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition the novelty score per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_nvlt_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_nvlt_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition the novelty score per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_nvlt_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_qc_mtrcs_dnst.pdf"
                    },
                    "doc": "QC metrics per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_qc_mtrcs_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_qc_mtrcs_dnst.png"
                    },
                    "doc": "QC metrics per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_qc_mtrcs_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_umi_dnst.pdf"
                    },
                    "doc": "UMI per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_umi_dnst_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_umi_dnst.png"
                    },
                    "doc": "UMI per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_umi_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_umi_dnst_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition UMI per cell density (not filtered).\nPDF format\n",
                    "id": "#sc-rna-filter.cwl/raw_umi_dnst_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_umi_dnst_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition UMI per cell density (not filtered).\nPNG format\n",
                    "id": "#sc-rna-filter.cwl/raw_umi_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_data.h5seurat"
                    },
                    "doc": "Filtered Seurat data in h5seurat format\n",
                    "id": "#sc-rna-filter.cwl/seurat_data_h5seurat"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_data.rds"
                    },
                    "doc": "Filtered Seurat data in RDS format\n",
                    "id": "#sc-rna-filter.cwl/seurat_data_rds"
                },
                {
                    "type": "File",
                    "id": "#sc-rna-filter.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "sc_rna_filter_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#sc-rna-filter.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "sc_rna_filter_stdout.log"
                    }
                }
            ],
            "baseCommand": [
                "sc_rna_filter.R"
            ],
            "arguments": [
                {
                    "valueFrom": "${\n  if (inputs.aggregation_metadata) {\n    return inputs.aggregation_metadata;\n  } else {\n    return runtime.outdir + \"/dummy_metadata.csv\"\n  }\n}\n",
                    "prefix": "--identity"
                }
            ],
            "stdout": "sc_rna_filter_stdout.log",
            "stderr": "sc_rna_filter_stderr.log",
            "label": "Single-cell RNA-Seq Filtering Analysis",
            "doc": "Single-cell RNA-Seq Filtering Analysis\n\nFilters single-cell RNA-Seq datasets based on the common QC metrics.\n",
            "id": "#sc-rna-filter.cwl",
            "http://schema.org/name": "Single-cell RNA-Seq Filtering Analysis",
            "http://schema.org/alternateName": "Filters single-cell RNA-Seq datasets based on the common QC metrics",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/scRNA-Seq-Analysis/main/tools/sc-rna-filter.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/scRNA-Seq-Analysis",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "$(inputs.vector_memory_limit * 1000000000)",
                            "envName": "R_MAX_VSIZE"
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/sc-tools:v0.0.4"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--barcodes"
                    },
                    "doc": "Path to the headerless TSV/CSV file with the list of barcodes to select\ncells of interest (one barcode per line). Prefilters loaded Seurat object\nto include only specific set of cells.\nDefault: use all cells.\n",
                    "id": "#sc-rna-reduce.cwl/barcodes_data"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--cellcycle"
                    },
                    "doc": "Path to the TSV/CSV file with the information for cell cycle score assignment.\nFirst column - 'phase', second column 'gene_id'. If loaded Seurat object already\nincludes cell cycle scores in 'S.Score' and 'G2M.Score' metatada columns they will\nbe removed.\nDefault: skip cell cycle score assignment.\n",
                    "id": "#sc-rna-reduce.cwl/cell_cycle_data"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--dimensions"
                    },
                    "doc": "Dimensionality to use in UMAP projection (from 1 to 50). If single value N\nis provided, use from 1 to N PCs. If multiple values are provided, subset to\nonly selected PCs.\nDefault: from 1 to 10\n",
                    "id": "#sc-rna-reduce.cwl/dimensions"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--h5seurat"
                    },
                    "doc": "Save Seurat data to h5seurat file.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/export_h5seurat_data"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--pdf"
                    },
                    "doc": "Export plots in PDF.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/export_pdf_plots"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--cbbuild"
                    },
                    "doc": "Export results to UCSC Cell Browser. Default: false\n",
                    "id": "#sc-rna-reduce.cwl/export_ucsc_cb"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--highvargenes"
                    },
                    "doc": "Number of highly variable genes used in datasets integration, scaling and\ndimensionality reduction.\nDefault: 3000\n",
                    "id": "#sc-rna-reduce.cwl/highly_var_genes_count"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#sc-rna-reduce.cwl/integration_method/seurat",
                                "#sc-rna-reduce.cwl/integration_method/none"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--ntgr"
                    },
                    "doc": "Integration method used for joint analysis of multiple datasets. Automatically\nset to 'none' if loaded Suerat object includes only one dataset.\nDefault: seurat\n",
                    "id": "#sc-rna-reduce.cwl/integration_method"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--lowmem"
                    },
                    "doc": "Attempts to minimize RAM usage when integrating multiple datasets\nwith SCTransform algorithm (slows down the computation). Ignored if\n'--ntgr' is not set to 'seurat' or if '--norm' is not set to either\n'sct' or 'sctglm'.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/low_memory"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#sc-rna-reduce.cwl/normalization_method/sct",
                                "#sc-rna-reduce.cwl/normalization_method/log",
                                "#sc-rna-reduce.cwl/normalization_method/sctglm"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--norm"
                    },
                    "doc": "Normalization method applied to genes expression counts. If loaded Seurat object\nincludes multiple datasets, normalization will be run independently for each of\nthem, unless integration is disabled with --ntgr set to 'none'\nDefault: sct\n",
                    "id": "#sc-rna-reduce.cwl/normalization_method"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "Output prefix.\nDefault: ./sc\n",
                    "id": "#sc-rna-reduce.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--memory"
                    },
                    "doc": "Maximum memory in GB allowed to be shared between the workers\nwhen using multiple --cpus.\nDefault: 32\n",
                    "id": "#sc-rna-reduce.cwl/parallel_memory_limit"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--query"
                    },
                    "doc": "Path to the RDS file to load Seurat object from. This file should include genes\nexpression information stored in the RNA assay.\n",
                    "id": "#sc-rna-reduce.cwl/query_data_rds"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--regresscellcycle"
                    },
                    "doc": "Regress cell cycle scores as a confounding source of variation.\nIgnored if --cellcycle is not provided.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/regress_cellcycle"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--regressgenes"
                    },
                    "doc": "Regress genes per cell counts as a confounding source of variation.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/regress_genes"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--regressmt"
                    },
                    "doc": "Regress the percentage of transcripts mapped to mitochondrial genes as a\nconfounding source of variation.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/regress_mito_perc"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--regressrnaumi"
                    },
                    "doc": "Regress UMI per cell counts as a confounding source of variation.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/regress_rna_umi"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cpus"
                    },
                    "doc": "Number of cores/cpus to use.\nDefault: 1\n",
                    "id": "#sc-rna-reduce.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#sc-rna-reduce.cwl/umap_method/uwot",
                                "#sc-rna-reduce.cwl/umap_method/uwot-learn",
                                "#sc-rna-reduce.cwl/umap_method/umap-learn"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--umethod"
                    },
                    "doc": "UMAP implementation to run. If set to 'umap-learn' use --umetric 'correlation'\nDefault: uwot\n",
                    "id": "#sc-rna-reduce.cwl/umap_method"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#sc-rna-reduce.cwl/umap_metric/euclidean",
                                "#sc-rna-reduce.cwl/umap_metric/manhattan",
                                "#sc-rna-reduce.cwl/umap_metric/chebyshev",
                                "#sc-rna-reduce.cwl/umap_metric/minkowski",
                                "#sc-rna-reduce.cwl/umap_metric/canberra",
                                "#sc-rna-reduce.cwl/umap_metric/braycurtis",
                                "#sc-rna-reduce.cwl/umap_metric/mahalanobis",
                                "#sc-rna-reduce.cwl/umap_metric/wminkowski",
                                "#sc-rna-reduce.cwl/umap_metric/seuclidean",
                                "#sc-rna-reduce.cwl/umap_metric/cosine",
                                "#sc-rna-reduce.cwl/umap_metric/correlation",
                                "#sc-rna-reduce.cwl/umap_metric/haversine",
                                "#sc-rna-reduce.cwl/umap_metric/hamming",
                                "#sc-rna-reduce.cwl/umap_metric/jaccard",
                                "#sc-rna-reduce.cwl/umap_metric/dice",
                                "#sc-rna-reduce.cwl/umap_metric/russelrao",
                                "#sc-rna-reduce.cwl/umap_metric/kulsinski",
                                "#sc-rna-reduce.cwl/umap_metric/ll_dirichlet",
                                "#sc-rna-reduce.cwl/umap_metric/hellinger",
                                "#sc-rna-reduce.cwl/umap_metric/rogerstanimoto",
                                "#sc-rna-reduce.cwl/umap_metric/sokalmichener",
                                "#sc-rna-reduce.cwl/umap_metric/sokalsneath",
                                "#sc-rna-reduce.cwl/umap_metric/yule"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--umetric"
                    },
                    "doc": "The metric to use to compute distances in high dimensional space for UMAP.\nDefault: cosine\n",
                    "id": "#sc-rna-reduce.cwl/umap_metric"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--umindist"
                    },
                    "doc": "Controls how tightly the embedding is allowed compress points together on UMAP.\nLarger values ensure embedded points are moreevenly distributed, while smaller\nvalues allow the algorithm to optimise more accurately with regard to local structure.\nSensible values are in the range 0.001 to 0.5.\nDefault:  0.3\n",
                    "id": "#sc-rna-reduce.cwl/umap_mindist"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--uneighbors"
                    },
                    "doc": "Determines the number of neighboring points used in UMAP. Larger values will result\nin more global structure being preserved at the loss of detailed local structure.\nIn general this parameter should often be in the range 5 to 50.\nDefault: 30\n",
                    "id": "#sc-rna-reduce.cwl/umap_neighbors"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--uspread"
                    },
                    "doc": "The effective scale of embedded points on UMAP. In combination with '--mindist'\nit determines how clustered/clumped the embedded points are.\nDefault: 1\n",
                    "id": "#sc-rna-reduce.cwl/umap_spread"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 128,
                    "doc": "Maximum vector memory in GB allowed to be used by R.\nDefault: 128\n",
                    "id": "#sc-rna-reduce.cwl/vector_memory_limit"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--verbose"
                    },
                    "doc": "Print debug information.\nDefault: false\n",
                    "id": "#sc-rna-reduce.cwl/verbose"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_elbow.pdf"
                    },
                    "doc": "Elbow plot (from cells PCA).\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/elbow_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_elbow.png"
                    },
                    "doc": "Elbow plot (from cells PCA).\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/elbow_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_qc_dim_corr.pdf"
                    },
                    "doc": "Correlation plots between QC metrics and cells PCA components.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/qc_dim_corr_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_qc_dim_corr.png"
                    },
                    "doc": "Correlation plots between QC metrics and cells PCA components.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/qc_dim_corr_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_data.h5seurat"
                    },
                    "doc": "Reduced Seurat data in h5seurat format\n",
                    "id": "#sc-rna-reduce.cwl/seurat_data_h5seurat"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_data.rds"
                    },
                    "doc": "Reduced Seurat data in RDS format\n",
                    "id": "#sc-rna-reduce.cwl/seurat_data_rds"
                },
                {
                    "type": "File",
                    "id": "#sc-rna-reduce.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "sc_rna_reduce_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#sc-rna-reduce.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "sc_rna_reduce_stdout.log"
                    }
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "*_cellbrowser"
                    },
                    "doc": "Directory with UCSC Cellbrowser configuration data.\n",
                    "id": "#sc-rna-reduce.cwl/ucsc_cb_config_data"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "*_cellbrowser/html_data"
                    },
                    "doc": "Directory with UCSC Cellbrowser html data.\n",
                    "id": "#sc-rna-reduce.cwl/ucsc_cb_html_data"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_cellbrowser/html_data/index.html"
                    },
                    "doc": "HTML index file from the directory with UCSC Cellbrowser html data.\n",
                    "id": "#sc-rna-reduce.cwl/ucsc_cb_html_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_gene.pdf"
                    },
                    "doc": "Grouped by condition split by the genes per cell counts cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_gene_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_gene.png"
                    },
                    "doc": "Grouped by condition split by the genes per cell counts cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_gene_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_mito.pdf"
                    },
                    "doc": "Grouped by condition split by the percentage of transcripts mapped to mitochondrial genes cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_mito_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_mito.png"
                    },
                    "doc": "Grouped by condition split by the percentage of transcripts mapped to mitochondrial genes cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_mito_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_ph.pdf"
                    },
                    "doc": "Grouped by condition split by cell cycle cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_ph_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_ph.png"
                    },
                    "doc": "Grouped by condition split by cell cycle cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_ph_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_umi.pdf"
                    },
                    "doc": "Grouped by condition split by the UMI per cell counts cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_umi_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_gr_cnd_spl_umi.png"
                    },
                    "doc": "Grouped by condition split by the UMI per cell counts cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_gr_cnd_spl_umi_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap.pdf"
                    },
                    "doc": "Cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap.png"
                    },
                    "doc": "Cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_qc_mtrcs.pdf"
                    },
                    "doc": "QC metrics on cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_qc_mtrcs_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_qc_mtrcs.png"
                    },
                    "doc": "QC metrics on cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_qc_mtrcs_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_cnd.pdf"
                    },
                    "doc": "Split by grouping condition cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_cnd_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_cnd.png"
                    },
                    "doc": "Split by grouping condition cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_gene.pdf"
                    },
                    "doc": "Split by the genes per cell counts cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_gene_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_gene.png"
                    },
                    "doc": "Split by the genes per cell counts cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_gene_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_idnt.pdf"
                    },
                    "doc": "Split by dataset cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_idnt_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_idnt.png"
                    },
                    "doc": "Split by dataset cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_idnt_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_mito.pdf"
                    },
                    "doc": "Split by the percentage of transcripts mapped to mitochondrial genes cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_mito_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_mito.png"
                    },
                    "doc": "Split by the percentage of transcripts mapped to mitochondrial genes cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_mito_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_ph.pdf"
                    },
                    "doc": "Split by cell cycle phase cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_ph_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_ph.png"
                    },
                    "doc": "Split by cell cycle phase cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_ph_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_umi.pdf"
                    },
                    "doc": "Split by the UMI per cell counts cells UMAP.\nPDF format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_umi_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_umap_spl_umi.png"
                    },
                    "doc": "Split by the UMI per cell counts cells UMAP.\nPNG format\n",
                    "id": "#sc-rna-reduce.cwl/umap_spl_umi_plot_png"
                }
            ],
            "baseCommand": [
                "sc_rna_reduce.R"
            ],
            "stdout": "sc_rna_reduce_stdout.log",
            "stderr": "sc_rna_reduce_stderr.log",
            "label": "Single-cell RNA-Seq Dimensionality Reduction Analysis",
            "doc": "Single-cell RNA-Seq Dimensionality Reduction Analysis\n\nIntegrates multiple single-cell RNA-Seq datasets, reduces dimensionality using PCA.\n",
            "id": "#sc-rna-reduce.cwl",
            "http://schema.org/name": "Single-cell RNA-Seq Dimensionality Reduction Analysis",
            "http://schema.org/alternateName": "Integrates multiple single-cell RNA-Seq datasets, reduces dimensionality using PCA",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/scRNA-Seq-Analysis/main/tools/sc-rna-reduce.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/scRNA-Seq-Analysis",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:20.04"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "File to extract",
                    "id": "#tar-extract.cwl/file_to_extract"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "doc": "Extracted folder",
                    "id": "#tar-extract.cwl/extracted_folder"
                }
            ],
            "baseCommand": [
                "tar",
                "xzf"
            ],
            "label": "TAR extract",
            "doc": "TAR extract\n\nExtracts the content of TAR file into a folder.",
            "id": "#tar-extract.cwl",
            "http://schema.org/name": "TAR extract",
            "http://schema.org/alternateName": "Extracts the content of TAR file into a folder",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/scRNA-Seq-Analysis/main/tools/tar-extract.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/scRNA-Seq-Analysis",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Path to the metadata TSV/CSV file to set the datasets identities. If '--mex' points to\nthe Cell Ranger Aggregate outputs, the aggregation.csv file can be used. If input is not\nprovided, the default dummy_metadata.csv will be used instead.\n",
                    "id": "#main/aggregation_metadata"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Path to the headerless TSV/CSV file with the list of barcodes to select\ncells of interest (one barcode per line). Prefilters input feature-barcode\nmatrix to include only selected cells.\nDefault: use all cells.\n",
                    "id": "#main/barcodes_data"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Path to the TSV/CSV file with the information for cell cycle score assignment.\nFirst column - 'phase', second column 'gene_id'. If loaded Seurat object already\nincludes cell cycle scores in 'S.Score' and 'G2M.Score' metatada columns they will\nbe removed.\nDefault: skip cell cycle score assignment.\n",
                    "id": "#main/cell_cycle_data"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/cluster_metric/euclidean",
                                "#main/cluster_metric/cosine",
                                "#main/cluster_metric/manhattan",
                                "#main/cluster_metric/hamming"
                            ]
                        }
                    ],
                    "doc": "Distance metric used when constructing nearest-neighbor graph before clustering.\nDefault: euclidean\n",
                    "id": "#main/cluster_metric"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "doc": "Dimensionality to use in UMAP projection and when constructing nearest-neighbor\ngraph before clustering (from 1 to 50). If single value N is provided, use from\n1 to N dimensions. If multiple values are provided, subset to only selected\ndimensions.\nDefault: from 1 to 10\n",
                    "id": "#main/dimensions"
                },
                {
                    "type": "File",
                    "doc": "Path to the compressed folder with feature-barcode matrix from Cell Ranger Count/Aggregate\nexperiment in MEX format.\n",
                    "id": "#main/feature_bc_matrices_folder"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "Genes of interest to build genes expression plots.\nDefault: None\n",
                    "id": "#main/genes_of_interest"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Path to the TSV/CSV file to define datasets grouping. First column - 'library_id'\nwith the values and order that correspond to the 'library_id' column from the\n'--identity' file, second column 'condition'.\nDefault: each dataset is assigned to its own group.\n",
                    "id": "#main/grouping_data"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of highly variable genes used in datasets integration, scaling and\ndimensionality reduction.\nDefault: 3000\n",
                    "id": "#main/highly_var_genes_count"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Identify differentially expressed genes (putative gene markers) between each\npair of clusters for all resolutions.\nDefault: false\n",
                    "id": "#main/identify_diff_genes"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/integration_method/seurat",
                                "#main/integration_method/none"
                            ]
                        }
                    ],
                    "doc": "Integration method used for joint analysis of multiple datasets. Automatically\nset to 'none' if loaded Suerat object includes only one dataset.\nDefault: seurat\n",
                    "id": "#main/integration_method"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "doc": "Include cells with the number of genes not bigger than this value. If multiple\nvalues provided, each of them will be applied to the correspondent dataset from\nthe '--mex' input based on the '--identity' file.\nDefault: 5000 (applied to all datasets)\n",
                    "id": "#main/maximum_genes"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Include cells with the percentage of transcripts mapped to mitochondrial\ngenes not bigger than this value.\nDefault: 5 (applied to all datasets)\n",
                    "id": "#main/maximum_mito_perc"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "doc": "Include cells where at least this many genes are detected. If multiple values\nprovided, each of them will be applied to the correspondent dataset from the\n'--mex' input based on the '--identity' file.\nDefault: 250 (applied to all datasets)\n",
                    "id": "#main/minimum_genes"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "For putative gene markers identification include only those genes that\non average have log fold change difference in expression between every\ntested pair of clusters not lower than this value. Ignored if '--diffgenes'\nis not set.\nDefault: 0.25\n",
                    "id": "#main/minimum_logfc"
                },
                {
                    "type": [
                        "null",
                        "float",
                        {
                            "type": "array",
                            "items": "float"
                        }
                    ],
                    "doc": "Include cells with the novelty score not lower than this value, calculated for\nas log10(genes)/log10(UMI). If multiple values provided, each of them will\nbe applied to the correspondent dataset from the '--mex' input based on the\n'--identity' file.\nDefault: 0.8 (applied to all datasets)\n",
                    "id": "#main/minimum_novelty_score"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "For putative gene markers identification include only those genes that\nare detected in not lower than this fraction of cells in either of the\ntwo tested clusters. Ignored if '--diffgenes' is not set.\nDefault: 0.1\n",
                    "id": "#main/minimum_pct"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Regex pattern to identify mitochondrial genes.\nDefault: '^Mt-'\n",
                    "id": "#main/mito_pattern"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/normalization_method/sct",
                                "#main/normalization_method/log",
                                "#main/normalization_method/sctglm"
                            ]
                        }
                    ],
                    "doc": "Normalization method applied to genes expression counts. If loaded Seurat object\nincludes multiple datasets, normalization will be run independently for each of\nthem, unless integration is disabled with --ntgr set to 'none'\nDefault: sct\n",
                    "id": "#main/normalization_method"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "For putative gene markers identification return only positive markers.\nIgnored if '--diffgenes' is not set.\nDefault: false\n",
                    "id": "#main/only_positive_diff_genes"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Maximum memory in GB allowed to be shared between the workers\nwhen using multiple --cpus.\nDefault: 32\n",
                    "id": "#main/parallel_memory_limit"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Regress cell cycle scores as a confounding source of variation.\nIgnored if --cellcycle is not provided.\nDefault: false\n",
                    "id": "#main/regress_cellcycle"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Regress genes per cell counts as a confounding source of variation.\nDefault: false\n",
                    "id": "#main/regress_genes"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Regress the percentage of transcripts mapped to mitochondrial genes as a\nconfounding source of variation.\nDefault: false\n",
                    "id": "#main/regress_mito_perc"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Regress UMI per cell counts as a confounding source of variation.\nDefault: false\n",
                    "id": "#main/regress_rna_umi"
                },
                {
                    "type": [
                        "null",
                        "float",
                        {
                            "type": "array",
                            "items": "float"
                        }
                    ],
                    "doc": "Clustering resolution applied to the constructed nearest-neighbor graph.\nCan be set as an array.\nDefault: 0.3, 0.5, 1.0\n",
                    "id": "#main/resolution"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Include only genes detected in at least this many cells.\nDefault: 5 (applied to all datasets)\n",
                    "id": "#main/rna_minimum_cells"
                },
                {
                    "type": [
                        "null",
                        "int",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "doc": "Include cells where at least this many UMI (transcripts) are detected.\nIf multiple values provided, each of them will be applied to the correspondent\ndataset from the '--mex' input based on the '--identity' file.\nDefault: 500 (applied to all datasets)\n",
                    "id": "#main/rna_minimum_umi"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/test_to_use/wilcox",
                                "#main/test_to_use/bimod",
                                "#main/test_to_use/roc",
                                "#main/test_to_use/t",
                                "#main/test_to_use/negbinom",
                                "#main/test_to_use/poisson",
                                "#main/test_to_use/LR",
                                "#main/test_to_use/MAST",
                                "#main/test_to_use/DESeq2"
                            ]
                        }
                    ],
                    "doc": "Statistical test to use for putative gene markers identification.\nIgnored if '--diffgenes' is not set.\nDefault: wilcox\n",
                    "id": "#main/test_to_use"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Number of cores/cpus to use.\nDefault: 1\n",
                    "id": "#main/threads"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/umap_method/uwot",
                                "#main/umap_method/uwot-learn",
                                "#main/umap_method/umap-learn"
                            ]
                        }
                    ],
                    "doc": "UMAP implementation to run. If set to 'umap-learn' use --umetric 'correlation'\nDefault: uwot\n",
                    "id": "#main/umap_method"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/umap_metric/euclidean",
                                "#main/umap_metric/manhattan",
                                "#main/umap_metric/chebyshev",
                                "#main/umap_metric/minkowski",
                                "#main/umap_metric/canberra",
                                "#main/umap_metric/braycurtis",
                                "#main/umap_metric/mahalanobis",
                                "#main/umap_metric/wminkowski",
                                "#main/umap_metric/seuclidean",
                                "#main/umap_metric/cosine",
                                "#main/umap_metric/correlation",
                                "#main/umap_metric/haversine",
                                "#main/umap_metric/hamming",
                                "#main/umap_metric/jaccard",
                                "#main/umap_metric/dice",
                                "#main/umap_metric/russelrao",
                                "#main/umap_metric/kulsinski",
                                "#main/umap_metric/ll_dirichlet",
                                "#main/umap_metric/hellinger",
                                "#main/umap_metric/rogerstanimoto",
                                "#main/umap_metric/sokalmichener",
                                "#main/umap_metric/sokalsneath",
                                "#main/umap_metric/yule"
                            ]
                        }
                    ],
                    "doc": "The metric to use to compute distances in high dimensional space for UMAP.\nDefault: cosine\n",
                    "id": "#main/umap_metric"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Controls how tightly the embedding is allowed compress points together on UMAP.\nLarger values ensure embedded points are moreevenly distributed, while smaller\nvalues allow the algorithm to optimise more accurately with regard to local structure.\nSensible values are in the range 0.001 to 0.5.\nDefault:  0.3\n",
                    "id": "#main/umap_mindist"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Determines the number of neighboring points used in UMAP. Larger values will result\nin more global structure being preserved at the loss of detailed local structure.\nIn general this parameter should often be in the range 5 to 50.\nDefault: 30\n",
                    "id": "#main/umap_neighbors"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "The effective scale of embedded points on UMAP. In combination with '--mindist'\nit determines how clustered/clumped the embedded points are.\nDefault: 1\n",
                    "id": "#main/umap_spread"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Maximum vector memory in GB allowed to be used by R.\nDefault: 128\n",
                    "id": "#main/vector_memory_limit"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/cmp_gr_clst_spl_cnd_res_plot_png",
                    "doc": "Grouped by cluster split by condition cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#main/cmp_gr_clst_spl_cnd_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/cmp_gr_clst_spl_idnt_res_plot_png",
                    "doc": "Grouped by cluster split by dataset cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#main/cmp_gr_clst_spl_idnt_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/cmp_gr_cnd_spl_clst_res_plot_png",
                    "doc": "Grouped by condition split by cluster cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#main/cmp_gr_cnd_spl_clst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/cmp_gr_idnt_spl_clst_res_plot_png",
                    "doc": "Grouped by dataset split by cluster cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#main/cmp_gr_idnt_spl_clst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/cmp_gr_ph_spl_clst_res_plot_png",
                    "doc": "Grouped by cell cycle phase split by cluster cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#main/cmp_gr_ph_spl_clst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/cmp_gr_ph_spl_idnt_res_plot_png",
                    "doc": "Grouped by cell cycle phase split by dataset cells composition plot. Downsampled.\nPNG format\n",
                    "id": "#main/cmp_gr_ph_spl_idnt_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/elbow_plot_png",
                    "doc": "Elbow plot (from cells PCA).\nPNG format\n",
                    "id": "#main/elbow_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_1_2_qc_mtrcs_pca_plot_png",
                    "doc": "PC1 and PC2 from the QC metrics PCA (filtered).\nPNG format\n",
                    "id": "#main/fltr_1_2_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_2_3_qc_mtrcs_pca_plot_png",
                    "doc": "PC2 and PC3 from the QC metrics PCA (filtered).\nPNG format\n",
                    "id": "#main/fltr_2_3_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_cells_count_plot_png",
                    "doc": "Number of cells per dataset (filtered).\nPNG format\n",
                    "id": "#main/fltr_cells_count_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_gene_dnst_plot_png",
                    "doc": "Genes per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_gene_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_gene_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition genes per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_gene_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_gene_umi_corr_plot_png",
                    "doc": "Genes vs UMI per cell correlation (filtered).\nPNG format\n",
                    "id": "#main/fltr_gene_umi_corr_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_mito_dnst_plot_png",
                    "doc": "Percentage of transcripts mapped to mitochondrial genes per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_mito_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_mito_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition the percentage of transcripts mapped\nto mitochondrial genes per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_mito_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_nvlt_dnst_plot_png",
                    "doc": "Novelty score per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_nvlt_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_nvlt_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition the novelty score per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_nvlt_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_qc_mtrcs_dnst_plot_png",
                    "doc": "QC metrics per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_qc_mtrcs_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_umi_dnst_plot_png",
                    "doc": "UMI per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_umi_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/fltr_umi_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition UMI per cell density (filtered).\nPNG format\n",
                    "id": "#main/fltr_umi_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_cluster/gene_markers_tsv",
                    "doc": "Differentially expressed genes between each pair of clusters for all resolutions.\nTSV format\n",
                    "id": "#main/gene_markers_tsv"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/qc_dim_corr_plot_png",
                    "doc": "Correlation plots between QC metrics and cells PCA components.\nPNG format\n",
                    "id": "#main/qc_dim_corr_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_1_2_qc_mtrcs_pca_plot_png",
                    "doc": "PC1 and PC2 from the QC metrics PCA (not filtered).\nPNG format\n",
                    "id": "#main/raw_1_2_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_2_3_qc_mtrcs_pca_plot_png",
                    "doc": "PC2 and PC3 from the QC metrics PCA (not filtered).\nPNG format\n",
                    "id": "#main/raw_2_3_qc_mtrcs_pca_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_cells_count_plot_png",
                    "doc": "Number of cells per dataset (not filtered).\nPNG format\n",
                    "id": "#main/raw_cells_count_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_gene_dnst_plot_png",
                    "doc": "Genes per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_gene_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_gene_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition genes per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_gene_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_gene_umi_corr_plot_png",
                    "doc": "Genes vs UMI per cell correlation (not filtered).\nPNG format\n",
                    "id": "#main/raw_gene_umi_corr_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_mito_dnst_plot_png",
                    "doc": "Percentage of transcripts mapped to mitochondrial genes per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_mito_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_mito_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition the percentage of transcripts mapped\nto mitochondrial genes per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_mito_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_nvlt_dnst_plot_png",
                    "doc": "Novelty score per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_nvlt_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_nvlt_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition the novelty score per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_nvlt_dnst_spl_cnd_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_qc_mtrcs_dnst_plot_png",
                    "doc": "QC metrics per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_qc_mtrcs_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_umi_dnst_plot_png",
                    "doc": "UMI per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_umi_dnst_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_filter/raw_umi_dnst_spl_cnd_plot_png",
                    "doc": "Split by grouping condition UMI per cell density (not filtered).\nPNG format\n",
                    "id": "#main/raw_umi_dnst_spl_cnd_plot_png"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sc_rna_cluster/stderr_log",
                    "doc": "stderr log generated by sc_rna_cluster step\n",
                    "id": "#main/sc_rna_cluster_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sc_rna_cluster/stdout_log",
                    "doc": "stdout log generated by sc_rna_cluster step\n",
                    "id": "#main/sc_rna_cluster_stdout_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sc_rna_filter/stderr_log",
                    "doc": "stderr log generated by sc_rna_filter step\n",
                    "id": "#main/sc_rna_filter_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sc_rna_filter/stdout_log",
                    "doc": "stdout log generated by sc_rna_filter step\n",
                    "id": "#main/sc_rna_filter_stdout_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sc_rna_reduce/stderr_log",
                    "doc": "stderr log generated by sc_rna_reduce step\n",
                    "id": "#main/sc_rna_reduce_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sc_rna_reduce/stdout_log",
                    "doc": "stdout log generated by sc_rna_reduce step\n",
                    "id": "#main/sc_rna_reduce_stdout_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sc_rna_cluster/seurat_data_rds",
                    "doc": "Processed Seurat data in RDS format\n",
                    "id": "#main/seurat_data_rds"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/slh_res_plot_png",
                    "doc": "Silhouette scores. Downsampled to max 500 cells per cluster.\nPNG format\n",
                    "id": "#main/slh_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/sc_rna_cluster/ucsc_cb_html_data",
                    "doc": "Directory with UCSC Cellbrowser html data.\n",
                    "id": "#main/ucsc_cb_html_data"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_gr_cnd_spl_gene_plot_png",
                    "doc": "Grouped by condition split by the genes per cell counts cells UMAP.\nPNG format\n",
                    "id": "#main/umap_gr_cnd_spl_gene_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_gr_cnd_spl_mito_plot_png",
                    "doc": "Grouped by condition split by the percentage of transcripts mapped to mitochondrial genes cells UMAP.\nPNG format\n",
                    "id": "#main/umap_gr_cnd_spl_mito_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_gr_cnd_spl_ph_plot_png",
                    "doc": "Grouped by condition split by cell cycle cells UMAP.\nPNG format\n",
                    "id": "#main/umap_gr_cnd_spl_ph_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_gr_cnd_spl_umi_plot_png",
                    "doc": "Grouped by condition split by the UMI per cell counts cells UMAP.\nPNG format\n",
                    "id": "#main/umap_gr_cnd_spl_umi_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_qc_mtrcs_plot_png",
                    "doc": "QC metrics on cells UMAP.\nPNG format\n",
                    "id": "#main/umap_qc_mtrcs_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/umap_res_plot_png",
                    "doc": "Clustered cells UMAP.\nPNG format\n",
                    "id": "#main/umap_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/umap_spl_cnd_res_plot_png",
                    "doc": "Split by grouping condition clustered cells UMAP.\nPNG format\n",
                    "id": "#main/umap_spl_cnd_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_spl_gene_plot_png",
                    "doc": "Split by the genes per cell counts cells UMAP.\nPNG format\n",
                    "id": "#main/umap_spl_gene_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/umap_spl_idnt_res_plot_png",
                    "doc": "Split by dataset clustered cells UMAP.\nPNG format\n",
                    "id": "#main/umap_spl_idnt_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_spl_mito_plot_png",
                    "doc": "Split by the percentage of transcripts mapped to mitochondrial genes cells UMAP.\nPNG format\n",
                    "id": "#main/umap_spl_mito_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/umap_spl_ph_res_plot_png",
                    "doc": "Split by cell cycle phase clustered cells UMAP.\nPNG format\n",
                    "id": "#main/umap_spl_ph_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/sc_rna_reduce/umap_spl_umi_plot_png",
                    "doc": "Split by the UMI per cell counts cells UMAP.\nPNG format\n",
                    "id": "#main/umap_spl_umi_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/xpr_avg_res_plot_png",
                    "doc": "Log normalized scaled average gene expression per cluster.\nPNG format\n",
                    "id": "#main/xpr_avg_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/xpr_dnst_res_plot_png",
                    "doc": "Log normalized gene expression density per cluster.\nPNG format\n",
                    "id": "#main/xpr_dnst_res_plot_png"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/sc_rna_cluster/xpr_per_cell_res_plot_png",
                    "doc": "Log normalized gene expression on cells UMAP.\nPNG format\n",
                    "id": "#main/xpr_per_cell_res_plot_png"
                }
            ],
            "steps": [
                {
                    "doc": "Clusters single-cell RNA-Seq datasets, identifies gene markers\n",
                    "run": "#sc-rna-cluster.cwl",
                    "in": [
                        {
                            "source": "#main/cluster_metric",
                            "id": "#main/sc_rna_cluster/cluster_metric"
                        },
                        {
                            "source": "#main/dimensions",
                            "id": "#main/sc_rna_cluster/dimensions"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_cluster/export_h5seurat_data"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_cluster/export_pdf_plots"
                        },
                        {
                            "default": true,
                            "id": "#main/sc_rna_cluster/export_ucsc_cb"
                        },
                        {
                            "source": "#main/genes_of_interest",
                            "id": "#main/sc_rna_cluster/genes_of_interest"
                        },
                        {
                            "source": "#main/identify_diff_genes",
                            "id": "#main/sc_rna_cluster/identify_diff_genes"
                        },
                        {
                            "source": "#main/minimum_logfc",
                            "id": "#main/sc_rna_cluster/minimum_logfc"
                        },
                        {
                            "source": "#main/minimum_pct",
                            "id": "#main/sc_rna_cluster/minimum_pct"
                        },
                        {
                            "source": "#main/only_positive_diff_genes",
                            "id": "#main/sc_rna_cluster/only_positive_diff_genes"
                        },
                        {
                            "default": "step_3",
                            "id": "#main/sc_rna_cluster/output_prefix"
                        },
                        {
                            "source": "#main/parallel_memory_limit",
                            "id": "#main/sc_rna_cluster/parallel_memory_limit"
                        },
                        {
                            "source": "#main/sc_rna_reduce/seurat_data_rds",
                            "id": "#main/sc_rna_cluster/query_data_rds"
                        },
                        {
                            "source": "#main/resolution",
                            "id": "#main/sc_rna_cluster/resolution"
                        },
                        {
                            "source": "#main/test_to_use",
                            "id": "#main/sc_rna_cluster/test_to_use"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/sc_rna_cluster/threads"
                        },
                        {
                            "source": "#main/vector_memory_limit",
                            "id": "#main/sc_rna_cluster/vector_memory_limit"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_cluster/verbose"
                        }
                    ],
                    "out": [
                        "#main/sc_rna_cluster/umap_res_plot_png",
                        "#main/sc_rna_cluster/slh_res_plot_png",
                        "#main/sc_rna_cluster/umap_spl_idnt_res_plot_png",
                        "#main/sc_rna_cluster/cmp_gr_clst_spl_idnt_res_plot_png",
                        "#main/sc_rna_cluster/cmp_gr_idnt_spl_clst_res_plot_png",
                        "#main/sc_rna_cluster/umap_spl_cnd_res_plot_png",
                        "#main/sc_rna_cluster/cmp_gr_clst_spl_cnd_res_plot_png",
                        "#main/sc_rna_cluster/cmp_gr_cnd_spl_clst_res_plot_png",
                        "#main/sc_rna_cluster/umap_spl_ph_res_plot_png",
                        "#main/sc_rna_cluster/cmp_gr_ph_spl_idnt_res_plot_png",
                        "#main/sc_rna_cluster/cmp_gr_ph_spl_clst_res_plot_png",
                        "#main/sc_rna_cluster/xpr_avg_res_plot_png",
                        "#main/sc_rna_cluster/xpr_per_cell_res_plot_png",
                        "#main/sc_rna_cluster/xpr_dnst_res_plot_png",
                        "#main/sc_rna_cluster/gene_markers_tsv",
                        "#main/sc_rna_cluster/ucsc_cb_html_data",
                        "#main/sc_rna_cluster/seurat_data_rds",
                        "#main/sc_rna_cluster/stdout_log",
                        "#main/sc_rna_cluster/stderr_log"
                    ],
                    "id": "#main/sc_rna_cluster"
                },
                {
                    "doc": "Filters single-cell RNA-Seq datasets based on the common QC metrics\n",
                    "run": "#sc-rna-filter.cwl",
                    "in": [
                        {
                            "source": "#main/aggregation_metadata",
                            "id": "#main/sc_rna_filter/aggregation_metadata"
                        },
                        {
                            "source": "#main/barcodes_data",
                            "id": "#main/sc_rna_filter/barcodes_data"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_filter/export_h5seurat_data"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_filter/export_pdf_plots"
                        },
                        {
                            "source": "#main/uncompress_feature_bc_matrices/extracted_folder",
                            "id": "#main/sc_rna_filter/feature_bc_matrices_folder"
                        },
                        {
                            "source": "#main/grouping_data",
                            "id": "#main/sc_rna_filter/grouping_data"
                        },
                        {
                            "source": "#main/maximum_genes",
                            "id": "#main/sc_rna_filter/maximum_genes"
                        },
                        {
                            "source": "#main/maximum_mito_perc",
                            "id": "#main/sc_rna_filter/maximum_mito_perc"
                        },
                        {
                            "source": "#main/minimum_genes",
                            "id": "#main/sc_rna_filter/minimum_genes"
                        },
                        {
                            "source": "#main/minimum_novelty_score",
                            "id": "#main/sc_rna_filter/minimum_novelty_score"
                        },
                        {
                            "source": "#main/mito_pattern",
                            "id": "#main/sc_rna_filter/mito_pattern"
                        },
                        {
                            "default": "step_1",
                            "id": "#main/sc_rna_filter/output_prefix"
                        },
                        {
                            "source": "#main/parallel_memory_limit",
                            "id": "#main/sc_rna_filter/parallel_memory_limit"
                        },
                        {
                            "source": "#main/rna_minimum_cells",
                            "id": "#main/sc_rna_filter/rna_minimum_cells"
                        },
                        {
                            "source": "#main/rna_minimum_umi",
                            "id": "#main/sc_rna_filter/rna_minimum_umi"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/sc_rna_filter/threads"
                        },
                        {
                            "source": "#main/vector_memory_limit",
                            "id": "#main/sc_rna_filter/vector_memory_limit"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_filter/verbose"
                        }
                    ],
                    "out": [
                        "#main/sc_rna_filter/raw_1_2_qc_mtrcs_pca_plot_png",
                        "#main/sc_rna_filter/raw_2_3_qc_mtrcs_pca_plot_png",
                        "#main/sc_rna_filter/raw_cells_count_plot_png",
                        "#main/sc_rna_filter/raw_umi_dnst_plot_png",
                        "#main/sc_rna_filter/raw_gene_dnst_plot_png",
                        "#main/sc_rna_filter/raw_gene_umi_corr_plot_png",
                        "#main/sc_rna_filter/raw_mito_dnst_plot_png",
                        "#main/sc_rna_filter/raw_nvlt_dnst_plot_png",
                        "#main/sc_rna_filter/raw_qc_mtrcs_dnst_plot_png",
                        "#main/sc_rna_filter/raw_umi_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/raw_gene_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/raw_mito_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/raw_nvlt_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/fltr_1_2_qc_mtrcs_pca_plot_png",
                        "#main/sc_rna_filter/fltr_2_3_qc_mtrcs_pca_plot_png",
                        "#main/sc_rna_filter/fltr_cells_count_plot_png",
                        "#main/sc_rna_filter/fltr_umi_dnst_plot_png",
                        "#main/sc_rna_filter/fltr_gene_dnst_plot_png",
                        "#main/sc_rna_filter/fltr_gene_umi_corr_plot_png",
                        "#main/sc_rna_filter/fltr_mito_dnst_plot_png",
                        "#main/sc_rna_filter/fltr_nvlt_dnst_plot_png",
                        "#main/sc_rna_filter/fltr_qc_mtrcs_dnst_plot_png",
                        "#main/sc_rna_filter/fltr_umi_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/fltr_gene_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/fltr_mito_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/fltr_nvlt_dnst_spl_cnd_plot_png",
                        "#main/sc_rna_filter/seurat_data_rds",
                        "#main/sc_rna_filter/stdout_log",
                        "#main/sc_rna_filter/stderr_log"
                    ],
                    "id": "#main/sc_rna_filter"
                },
                {
                    "doc": "Integrates multiple single-cell RNA-Seq datasets,\nreduces dimensionality using PCA\n",
                    "run": "#sc-rna-reduce.cwl",
                    "in": [
                        {
                            "source": "#main/cell_cycle_data",
                            "id": "#main/sc_rna_reduce/cell_cycle_data"
                        },
                        {
                            "source": "#main/dimensions",
                            "id": "#main/sc_rna_reduce/dimensions"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_reduce/export_h5seurat_data"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_reduce/export_pdf_plots"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_reduce/export_ucsc_cb"
                        },
                        {
                            "source": "#main/highly_var_genes_count",
                            "id": "#main/sc_rna_reduce/highly_var_genes_count"
                        },
                        {
                            "source": "#main/integration_method",
                            "id": "#main/sc_rna_reduce/integration_method"
                        },
                        {
                            "default": true,
                            "id": "#main/sc_rna_reduce/low_memory"
                        },
                        {
                            "source": "#main/normalization_method",
                            "id": "#main/sc_rna_reduce/normalization_method"
                        },
                        {
                            "default": "step_2",
                            "id": "#main/sc_rna_reduce/output_prefix"
                        },
                        {
                            "source": "#main/parallel_memory_limit",
                            "id": "#main/sc_rna_reduce/parallel_memory_limit"
                        },
                        {
                            "source": "#main/sc_rna_filter/seurat_data_rds",
                            "id": "#main/sc_rna_reduce/query_data_rds"
                        },
                        {
                            "source": "#main/regress_cellcycle",
                            "id": "#main/sc_rna_reduce/regress_cellcycle"
                        },
                        {
                            "source": "#main/regress_genes",
                            "id": "#main/sc_rna_reduce/regress_genes"
                        },
                        {
                            "source": "#main/regress_mito_perc",
                            "id": "#main/sc_rna_reduce/regress_mito_perc"
                        },
                        {
                            "source": "#main/regress_rna_umi",
                            "id": "#main/sc_rna_reduce/regress_rna_umi"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/sc_rna_reduce/threads"
                        },
                        {
                            "source": "#main/umap_method",
                            "id": "#main/sc_rna_reduce/umap_method"
                        },
                        {
                            "source": "#main/umap_metric",
                            "id": "#main/sc_rna_reduce/umap_metric"
                        },
                        {
                            "source": "#main/umap_mindist",
                            "id": "#main/sc_rna_reduce/umap_mindist"
                        },
                        {
                            "source": "#main/umap_neighbors",
                            "id": "#main/sc_rna_reduce/umap_neighbors"
                        },
                        {
                            "source": "#main/umap_spread",
                            "id": "#main/sc_rna_reduce/umap_spread"
                        },
                        {
                            "source": "#main/vector_memory_limit",
                            "id": "#main/sc_rna_reduce/vector_memory_limit"
                        },
                        {
                            "default": false,
                            "id": "#main/sc_rna_reduce/verbose"
                        }
                    ],
                    "out": [
                        "#main/sc_rna_reduce/elbow_plot_png",
                        "#main/sc_rna_reduce/qc_dim_corr_plot_png",
                        "#main/sc_rna_reduce/umap_qc_mtrcs_plot_png",
                        "#main/sc_rna_reduce/umap_spl_mito_plot_png",
                        "#main/sc_rna_reduce/umap_spl_umi_plot_png",
                        "#main/sc_rna_reduce/umap_spl_gene_plot_png",
                        "#main/sc_rna_reduce/umap_gr_cnd_spl_ph_plot_png",
                        "#main/sc_rna_reduce/umap_gr_cnd_spl_mito_plot_png",
                        "#main/sc_rna_reduce/umap_gr_cnd_spl_umi_plot_png",
                        "#main/sc_rna_reduce/umap_gr_cnd_spl_gene_plot_png",
                        "#main/sc_rna_reduce/seurat_data_rds",
                        "#main/sc_rna_reduce/stdout_log",
                        "#main/sc_rna_reduce/stderr_log"
                    ],
                    "id": "#main/sc_rna_reduce"
                },
                {
                    "doc": "Extracts the content of TAR file into a folder\n",
                    "run": "#tar-extract.cwl",
                    "in": [
                        {
                            "source": "#main/feature_bc_matrices_folder",
                            "id": "#main/uncompress_feature_bc_matrices/file_to_extract"
                        }
                    ],
                    "out": [
                        "#main/uncompress_feature_bc_matrices/extracted_folder"
                    ],
                    "id": "#main/uncompress_feature_bc_matrices"
                }
            ],
            "label": "Single-cell RNA-Seq Analyze",
            "doc": "Single-cell RNA-Seq Analyze\n\nRuns filtering, normalization, scaling, integration (optionally) and\nclustering for a single or aggregated single-cell RNA-Seq datasets.",
            "id": "#main",
            "http://schema.org/name": "Single-cell RNA-Seq Analyze",
            "http://schema.org/alternateName": "Runs filtering, normalization, scaling, integration (optionally) and\nclustering for a single or aggregated single-cell RNA-Seq datasets\n",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/scRNA-Seq-Analysis/main/workflows/sc-rna-analyze.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/scRNA-Seq-Analysis",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
